// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEWEBKIT_VERSION_H
#define KDEWEBKIT_VERSION_H

#define KDEWEBKIT_VERSION_STRING "5.39.0"
#define KDEWEBKIT_VERSION_MAJOR 5
#define KDEWEBKIT_VERSION_MINOR 39
#define KDEWEBKIT_VERSION_PATCH 0
#define KDEWEBKIT_VERSION ((5<<16)|(39<<8)|(0))

#endif
